/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RuleManagerController.as 4905 2009-08-13 13:35:13Z nicoulaj $
 * --------------------------------------------------------------------------
 */

package org.ow2.jasmine.monitoring.eos.rules.manager.control
{

import com.adobe.cairngorm.control.FrontController;

import org.ow2.jasmine.monitoring.eos.rules.common.event.RulePackagesEvent;
import org.ow2.jasmine.monitoring.eos.rules.common.event.SynchronizedRulePackageEvent;
import org.ow2.jasmine.monitoring.eos.rules.manager.command.*;
import org.ow2.jasmine.monitoring.eos.rules.manager.event.*;
import org.ow2.jasmine.monitoring.eos.rules.manager.model.RuleManagerModelLocator;
import org.ow2.jasmine.monitoring.eos.rules.manager.model.domain.RuleManagerModel;


/**
* Bind a type of command to an action.
* 
* @author Julien Nicoulaud
*/
public class RuleManagerController extends FrontController {

    // =========================================================================
    // Initialization
    // =========================================================================

    /**
    * Create an instance of the controller. Commands are initialized here.
    */
    public function RuleManagerController()
    {
        initialiseCommands();
    }

    /**
    * Add all of the commands to the pool of commands.
    */
    public function initialiseCommands() : void
    {
        // Retrieve the component model
        var model:RuleManagerModel = 
            RuleManagerModelLocator.getInstance().ruleManagerModel;
        
        // Register the commands
        this.addCommand(RuleManagerEvent.GET_RULE_PACKAGES + model.componentID,
                        GetRulePackagesCommand);
        this.addCommand(SynchronizedRulePackageEvent.SAVE_SYNCHRONIZED_RULE_PACKAGE + model.componentID,
                        SaveRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.DELETE_RULE_PACKAGE + model.componentID,
                        DeleteRulePackageCommand);
        this.addCommand(SynchronizedRulePackageEvent.COMPILE_RULE_PACKAGE + model.componentID,
                        CompileRulePackageCommand);
        this.addCommand(RulePackagesEvent.EXPORT_RULE_PACKAGES_AS_XML + model.componentID,
                        ExportRulePackagesAsXMLCommand);
    }
}
}
