/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: RuleManagerModel.as 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.rules.manager.model.domain
{
import mx.collections.ArrayCollection;
import mx.utils.UIDUtil;

import org.ow2.jasmine.monitoring.eos.rules.common.model.domain.SynchronizedRulePackage;
import org.ow2.jasmine.monitoring.eos.rules.manager.vo.*;


/**
* Cairngorm Model for the rule engine dashboard
* 
* @author Julien Nicoulaud
*/
[Bindable]
public class RuleManagerModel
{
	
    // =========================================================================
    // Variables
    // =========================================================================

    /**
    * The unique ID of this component
    * 
    * @internal
    *   Used to prevent a Cairngorm issue: when a command event is dispatched,
    * every controller that registered this event type receives it, even if
    * located in another module. To prevent this from happening and triggering
    * multiple severe unexpected concurrence bugs, each event dispatched is
    * postfixed with this unique ID.
    */
    public var componentID:String = UIDUtil.createUID();
    
    /**
    * The name of the service used by the component
    */
    public var serviceName:String;

    /**
    * The managed rule engine instance name
    */
    public var ruleEngineName:String;
    
    /**
    * The rule packages array
    */
    [ArrayElementType("org.ow2.jasmine.monitoring.eos.rules.common.model.domain.SynchronizedRulePackage")] 
    public var rulePackages : ArrayCollection = new ArrayCollection();
    
    /**
    * "Save" operations currently running counter
    * @internal dirty...
    */
    public var pendingSaveOperations : int = 0;
    
    
    // =========================================================================
    // Public methods
    // =========================================================================
    
    /**
    * Returns the index of a rule package identified by its systemName
    * @return -1 if the model does not contain the rulePackage
    */
    public function getRulePackageIndex(rulePackageSystemName:String):int
    {
    	for each (var rulePackage:SynchronizedRulePackage in rulePackages) {
    		if (rulePackage.rulePackage.systemName == rulePackageSystemName) {
    			return rulePackages.getItemIndex(rulePackage);
    		}
    	}
    	return -1;
    }
    
}
}
